# vidformer-py

[![PyPI version](https://img.shields.io/pypi/v/vidformer.svg)](https://pypi.org/project/vidformer/)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://github.com/ixlab/vidformer/blob/main/LICENSE)

vidformer-py is a Python 🐍 frontend for [vidformer](https://github.com/ixlab/vidformer).
It has an API compatibility layer with OpenCV cv2, as well as some [supervision](https://github.com/roboflow/supervision) annotators.
Our [getting started guide](https://ixlab.github.io/vidformer/docs/getting-started.html) explains how to use it.

**Quick links:**
* [📦 PyPI](https://pypi.org/project/vidformer/)
* [📘 Documentation - vidformer-py](https://ixlab.github.io/vidformer/vidformer-py/)
* [📘 Documentation - vidformer.cv2](https://ixlab.github.io/vidformer/vidformer-py/vidformer/cv2.html)
* [📘 Documentation - vidformer.supervision](https://ixlab.github.io/vidformer/vidformer-py/vidformer/supervision.html)
* [🧑‍💻 Source Code](https://github.com/ixlab/vidformer/tree/main/vidformer-py/)

**Publish:**
```bash
 export FLIT_USERNAME='__token__' FLIT_PASSWORD='<token>'
flit publish
```
